@@ -31,6 +31,9 @@ class pipeline_cli_config:  # pylint: disable=invalid-name
     pipeline_run_id: str = MISSING
     tags: Optional[Any] = None
     config_dir: Optional[str] = None
+    publish: bool = False
+    endpoint_name: Optional[str] = None
+    endpoint_description: Optional[str] = None
 
 
 @dataclass
