@@ -17,6 +17,7 @@ import jsonpath_ng
 from typing import Callable
 from hashlib import sha256
 from pathlib import Path
+import datetime
 
 try:
     import hydra
@@ -1391,20 +1392,43 @@ class AMLPipelineHelper:
             except BaseException as e:
                 log.error(f"An error occurred, recovery is not successful: {e}")
 
+    def _publish_to_endpoint(self, pipeline):
+        name = datetime.datetime.now()
+        endpoint_name = self.config.run.endpoint_name or self.config.run.experiment_name
+        endpoint_description = (
+            self.config.run.endpoint_description
+            or self.config.run.experiment_description
+        )
+
+        pipeline._publish_to_endpoint(
+            experiment_name=self.config.run.experiment_name,
+            name=name,
+            pipeline_endpoint_name=endpoint_name,
+            description=endpoint_description,
+            workspace=self.workspace(),
+        )
+        log.info(
+            f"Publishing pipeline as endpoint {endpoint_name} with name {name} to workspace {self.workspace()}."
+        )
+
     ################
     ### MAIN/RUN ###
     ################
 
     def connect(self):
         """Connect to the AML workspace using internal config"""
-        return azureml_connect(
-            aml_subscription_id=self.config.aml.subscription_id,
-            aml_resource_group=self.config.aml.resource_group,
-            aml_workspace_name=self.config.aml.workspace_name,
-            aml_auth=self.config.aml.auth,
-            aml_tenant=self.config.aml.tenant,
-            aml_force=self.config.aml.force,
-        )  # NOTE: this also stores aml workspace in internal global variable
+        # Only call azureml_connect if there is not an already a pre-existing workspace
+        try:
+            return current_workspace()
+        except:
+            return azureml_connect(
+                aml_subscription_id=self.config.aml.subscription_id,
+                aml_resource_group=self.config.aml.resource_group,
+                aml_workspace_name=self.config.aml.workspace_name,
+                aml_auth=self.config.aml.auth,
+                aml_tenant=self.config.aml.tenant,
+                aml_force=self.config.aml.force,
+            )  # NOTE: this also stores aml workspace in internal global variable
 
     def build_and_submit_new_pipeline(self):
         log.info(f"Building Pipeline [{self.__class__.__name__}]...")
@@ -1423,6 +1447,9 @@ class AMLPipelineHelper:
                     pipeline._get_graph_json(workspace=current_workspace())
                 )
 
+        if self.config.run.publish:
+            self._publish_to_endpoint(pipeline)
+
         if self.config.run.submit:
             pipeline_tags = self._parse_pipeline_tags()
             pipeline_tags.update({"shrike": __version__})
@@ -1520,6 +1547,7 @@ class AMLPipelineHelper:
                         )
                     except BaseException as e:
                         log.error(f"An error occurred, override is not successful: {e}")
+                        raise e
             try:
                 pipeline_run = self.build_and_submit_new_pipeline()
             except BaseException as e:
